@@ -14,7 +14,7 @@ from slai_cli.exceptions import InvalidHandlerSyntax
 from slai_cli.modules.docker_client import DockerClient
 from slai_cli import constants
 from slai_cli.errors import handle_error
-from slai_cli.create.local_config_helper import LocalConfigHelper
+from slai_cli.init.local_config_helper import LocalConfigHelper
 
 from slai.clients.cli import get_cli_client
 from slai.clients.model import get_model_client
