@@ -4,7 +4,7 @@ from pathlib import Path
 from slai.clients.cli import get_cli_client
 from slai.modules.notebook_utils import generate_trainer_from_template, parse_notebook
 from slai_cli import log
-from slai_cli.create.local_config_helper import LocalConfigHelper
+from slai_cli.init.local_config_helper import LocalConfigHelper
 
 
 def save_model(model_name):
