@@ -171,7 +171,7 @@ class DockerClient:
             [f"{req}{version}" for req, version in requirements.items()]
         )
         exit_code = self._run_interactive_command(
-            cmd=f"/workspace/env/{model_name}/bin/python -m pip install {req_string}"
+            cmd=f"/workspace/env/{model_name}/bin/python -m pip -q install {req_string}"  # noqa
         )
         return exit_code
 
